@@ -262,6 +262,13 @@ Fl_Light_Button *btnSpecial = (Fl_Light_Button *)0;
 Fl_Check_Button *btn_ext_tuner = (Fl_Check_Button *)0;
 Fl_Check_Button *btn_xcvr_auto_on = (Fl_Check_Button *)0;
 Fl_Check_Button *btn_xcvr_auto_off = (Fl_Check_Button *)0;
+Fl_Check_Button *btn_xcvr_synch_clock = (Fl_Check_Button *)0;
+Fl_Check_Button *btn_xcvr_synch_gmt = (Fl_Check_Button *)0;
+Fl_Button *btn_xcvr_synch_now = (Fl_Button *)0;
+Fl_Output *txt_xcvr_synch = (Fl_Output *)0;
+
+//Fl_Group  *kx3_extras = (Fl_Group *)0;
+//Fl_Check_Button *kxpa_enabled = (Fl_Check_Button *)0;
 
 Fl_Group  *genericUser_1 = (Fl_Group *)0;
 Fl_Button *btnUser1 = (Fl_Button*)0;
@@ -842,6 +849,22 @@ static void cb_btn_xcvr_auto_off(Fl_Check_Button* o, void*) {
 	progStatus.xcvr_auto_off = o->value();
 }
 
+static void cb_btn_xcvr_synch_clock( Fl_Check_Button* o, void*) {
+	progStatus.sync_clock = o->value();
+}
+
+static void cb_btn_xcvr_synch_gmt( Fl_Check_Button* o, void*) {
+	progStatus.sync_gmt = o->value();
+}
+
+static void cb_btn_xcvr_synch_now( Fl_Button *o, void *) {
+	synchronize_now();
+}
+
+//static void cb_kxpa_enabled(Fl_Check_Button* o, void *) {
+//	progStatus.kxpa = o->value();
+//}
+
 static void cb_btnUser( Fl_Button * o, void *d) {
 	long val = reinterpret_cast<long>(d);
 	if (((Fl::event_state() & FL_SHIFT) == FL_SHIFT) ||
