@@ -430,7 +430,12 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				btnAswapB = new Fl_Button(
 					btnA->x(), ypos,
 					btnA->w(), 20, _("A / B"));
-				btnAswapB->tooltip(_("Left click: Swap A/B\nRight click: Copy A to B"));
+					btnAswapB->tooltip(_("\
+Left click:Swap A/B\n\
+Right click:Copy A to B\n\
+SHIFT click: FreqA -> FreqB\n\
+CTRL  click: FreqB -> FreqA\
+"));
 				btnAswapB->down_box(FL_DOWN_BOX);
 				btnAswapB->labelsize(12);
 				btnAswapB->callback((Fl_Callback*)cb_btnAswapB);
