@@ -118,7 +118,7 @@ public:
 	int  get_PTT();
 
 	void set_power_control(double val);
-	int  get_power_control();
+	double get_power_control();
 	void get_pc_min_max_step(double &min, double &max, double &step);
 
 	void set_volume_control(int val);
@@ -176,6 +176,8 @@ public:
 	void set_xcvr_auto_on();
 	void set_xcvr_auto_off();
 
+	void sync_date(char *dt);
+	void sync_clock(char *tm);
 };
 
 #endif
