@@ -108,7 +108,7 @@ public:
 	int  get_alc(void);
 
 	void set_power_control(double val);
-	int  get_power_control();
+	double get_power_control();
 	void get_pc_min_max_step(double &min, double &max, double &step);
 
 	void set_rf_gain(int val);
@@ -152,6 +152,8 @@ public:
 	void set_band_selection(int v);
 	void get_band_selection(int v);
 
+	void sync_date(char *dt);
+	void sync_clock(char *tm);
 };
 
 #endif
