@@ -47,7 +47,7 @@ struct XCVR_STATE {
 	int  src;
 
 	int		split;
-	int		power_control;
+	double	power_control;
 	int		volume_control;
 	int		attenuator;
 	int		preamp;
@@ -111,17 +111,19 @@ struct XCVR_STATE {
 };
 
 enum {
-	vA,   // apply to vfoA
-	vB,   // apply to vfoB
-	vX,   // apply to current vfo
-	sA,  // select vfoA
-	sB,  // select vfoB
-	ON,  // ptt ON
-	OFF, // ptt OFF
-	sON, // split ON
-	sOFF, // split OFF
-	A2B,  // active to inactive vfo
-	SWAP  // swap vfo's
+	vA,    // apply to vfoA
+	vB,    // apply to vfoB
+	vX,    // apply to current vfo
+	sA,    // select vfoA
+	sB,    // select vfoB
+	ON,    // ptt ON
+	OFF,   // ptt OFF
+	sON,   // split ON
+	sOFF,  // split OFF
+	A2B,   // active to inactive vfo
+	SWAP,  // swap vfo's
+	FA2FB, // frequency vfoA -> vfoB
+	FB2FA  // frequency vfoA -> vfoB
 };
 
 struct VFOQUEUE {
@@ -284,6 +286,8 @@ public:
 
 	bool has_get_info;
 
+	bool can_synch_clock;
+
 // Icom Xcvr 
 	bool ICOMrig;
 	bool ICOMmainsub;
@@ -400,7 +404,7 @@ public:
 
 int po_, po_val;
 int pmax;
-	virtual int  get_power_control(void) {return po_;}
+	virtual double get_power_control(void) {return po_;}
 	virtual void set_power_control(double val) {po_ = val;}
 	virtual void get_pc_min_max_step(double &min, double &max, double &step) {
 		min = 0; pmax = max = 100; step = 1; }
@@ -533,10 +537,10 @@ int bfo_;
 	virtual void get_BFO_min_max_step(int &min, int &max, int &step) {
 		min = -100; max = 100; step = 1; }
 
-int vfo_;
+double vfo_;
 	virtual void setVfoAdj(double v) {vfo_ = v;}
 	virtual double getVfoAdj() {return vfo_;}
-	virtual void get_vfoadj_min_max_step(int &min, int &max, int &step) {
+	virtual void get_vfoadj_min_max_step(double &min, double &max, double &step) {
 		min = -100; max = 100; step = 1; }
 
 	virtual void set_line_out() {}
@@ -669,6 +673,14 @@ int vfo_;
 	virtual int power_max() {
 		return pmax;
 	}
+
+// date/time synchronize
+	virtual void sync_date(char *dt) {
+		printf("Synchronize date to: %s\n", dt);
+	}
+	virtual void sync_clock(char *tm) {
+		printf("Sychronize time to: %s\n", tm);
+	}
 };
 
 extern rigbase *rigs[];
