@@ -258,6 +258,9 @@ extern Fl_Light_Button *ic7610dual_watch;
 extern Fl_Light_Button *ic7610digi_sel_on_off;
 extern Fl_Wheel_Value_Slider *ic7610_digi_sel_val;
 
+//extern Fl_Group  *kx3_extras;
+//extern Fl_Check_Button *kxpa_enabled;
+
 extern Fl_Group  *genericUser_1;
 extern Fl_Button *btnUser1;
 extern Fl_Button *btnUser2;
@@ -316,6 +319,11 @@ extern Fl_Light_Button *btnSpecial;
 extern Fl_Check_Button *btn_ext_tuner;
 extern Fl_Check_Button *btn_xcvr_auto_on;
 extern Fl_Check_Button *btn_xcvr_auto_off;
+extern Fl_Check_Button *btn_xcvr_synch_clock;
+extern Fl_Check_Button *btn_xcvr_synch_gmt;
+extern Fl_Button *btn_xcvr_synch_now;
+extern Fl_Output *txt_xcvr_synch;
+
 extern Fl_Group *genericRXB;
 extern Hspinner *cntRIT;
 extern Hspinner *cntXIT;
@@ -543,6 +551,8 @@ extern Fl_Check_Button *poll_break_in;
 extern Fl_Button *btnClearAddControls;
 extern Fl_Check_Button *poll_all;
 extern Fl_Button *btnSetAllAdd;
+extern Fl_Check_Button *disable_polling;
+extern Fl_Check_Button *disable_xmlrpc;
 extern Fl_Group *tabSndCmd;
 
 extern Fl_Input2 *txt_command;
