@@ -183,6 +183,9 @@ struct status {
 	int		pwr_peak;
 	int		pwr_scale;
 
+	bool	sync_clock;
+	bool	sync_gmt;
+
 // ic7610 special controls
 	bool	digi_sel_on_off;
 	int		digi_sel_val;
@@ -349,6 +352,30 @@ struct status {
    string	command24;
    string	shftcmd24;
 
+   string	label_on_start1;
+   string	cmd_on_start1;
+
+   string	label_on_start2;
+   string	cmd_on_start2;
+
+   string	label_on_start3;
+   string	cmd_on_start3;
+
+   string	label_on_start4;
+   string	cmd_on_start4;
+
+   string	label_on_exit1;
+   string	cmd_on_exit1;
+
+   string	label_on_exit2;
+   string	cmd_on_exit2;
+
+   string	label_on_exit3;
+   string	cmd_on_exit3;
+
+   string	label_on_exit4;
+   string	cmd_on_exit4;
+
 // =========================
 	int		bg_red;
 	int		bg_green;
@@ -458,7 +485,7 @@ struct status {
 	int		gpio_pulse_width;
 
 // KXPA 100 presence
-	int		kxpa;
+//	int		kxpa;
 
 // cwio parameters
 	int		cwioWPM;
@@ -466,6 +493,7 @@ struct status {
 	int		cwioSHARED;
 	int		cwioPTT;
 	int		cwioCONNECTED;
+	int		cwioINVERTED;
 	double	cwio_comp;
 	string	cwioPORT;
 	string	cwio_msgs[12];
