@@ -122,6 +122,8 @@ extern void highlight_vfo(void *);
 extern void cb_set_split(int);
 extern void execute_swapAB();
 extern void execute_A2B();
+extern void execute_FA2FB();
+extern void execute_FB2FA();
 extern void cbAswapB();
 extern void cbRIT();
 extern void cbXIT();
@@ -257,6 +259,8 @@ extern void enable_yaesu_bandselect(int btn_num, bool enable = true);
 
 extern void break_in_label(const char *);
 
+extern void synchronize_now();
+
 // Display Dialog
 extern void cbUSBaudio();
 extern void cbCIVdefault();
@@ -323,17 +327,18 @@ extern void serial_timer(void *);
 
 extern void init_xmlrpc();
 
-extern void setFreqDispA(void *d);
-extern void setFreqDispB(void *d);
-extern void updateSmeter(void *d);
-extern void updateFwdPwr(void *d);
-extern void updateALC(void *d);
-extern void updateSWR(void *d);
-extern void updateSquelch(void *d);
-extern void updateRFgain(void *d);
-extern void zeroXmtMeters(void *d);
+extern void setFreqDispA(void *d = 0);
+extern void setFreqDispB(void *d = 0);
+extern void updateSmeter(void *d = 0);
+extern void updateFwdPwr(void *d = 0);
+extern void updateALC(void *d = 0);
+extern void updateSWR(void *d = 0);
+extern void updateSquelch(void *d = 0);
+extern void updateRFgain(void *d = 0);
+extern void zeroXmtMeters(void *d = 0);
 extern void set_power_controlImage(double);
-extern void update_UI_PTT(void *d = NULL);
+
+extern void update_UI_PTT(void *d = 0);
 
 extern void cb_send_command(string cmd, Fl_Output *resp = 0);
 extern const string lt_trim(const string& pString, const string& pWhitespace = " \"\t");
@@ -345,9 +350,10 @@ extern bool rig_notch;
 extern int rig_notch_val;
 extern void update_notch(void *d);
 
-extern int mval;
-extern int pwrval;
-extern int swrval;
+extern double smtrval;
+extern double pwrval;
+extern double swrval;
+extern double alcval;
 
 extern queue<VFOQUEUE> srvc_reqs;
 
