@@ -75,7 +75,7 @@ public:
 	int  get_swr();
 	int  get_alc();
 	int  get_power_out();
-	int  get_power_control();
+	double get_power_control();
 	void set_volume_control(int val);
 	void set_power_control(double val);
 	void get_pc_min_max_step(double &min, double &max, double &step) {
@@ -147,7 +147,7 @@ public:
 
 	void setVfoAdj(double v);
 	double getVfoAdj();
-	void get_vfoadj_min_max_step(int &min, int &max, int &step);
+	void get_vfoadj_min_max_step(double &min, double &max, double &step);
 
 };
 
