@@ -256,6 +256,8 @@ RIG_IC7100::RIG_IC7100() {
 
 	has_xcvr_auto_on_off = true;
 
+	can_synch_clock = true;
+
 	precision = 1;
 	ndigits = 9;
 	A.filter = B.filter = 1;
@@ -1262,7 +1264,7 @@ void RIG_IC7100::set_power_control(double val)
 	seth();
 }
 
-int RIG_IC7100::get_power_control()
+double RIG_IC7100::get_power_control()
 {
 	int val = progStatus.power_level;
 	string cstr = "\x14\x0A";
@@ -2202,3 +2204,52 @@ std::string RIG_IC7100::get_FILTERS()
 		s << mode_filterB[i] << " ";
 	return s.str();
 }
+
+// ---------------------------------------------------------------------
+// set date and time
+// 1A 05 00 95 HH MM : set time
+// 1A 05 00 94 YY YY MM DD : set date
+// ---------------------------------------------------------------------
+// dt formated as YYYYMMDD
+// ---------------------------------------------------------------------
+void RIG_IC7100::sync_date(char *dt)
+{
+	cmd.clear();
+	cmd.append(pre_to);
+	cmd += '\x1A'; cmd += '\x05';
+	cmd += '\x01'; cmd += '\x20';
+	unsigned char val;
+	val = ((dt[0] - '0') << 4) + (dt[1] - '0');
+	cmd += (val & 0xFF);
+	val = ((dt[2] - '0') << 4) + (dt[3] - '0');
+	cmd += (val & 0xFF);
+	val = ((dt[4] - '0') << 4) + (dt[5] - '0');
+	cmd += (val & 0xFF);
+	val = ((dt[6] - '0') << 4) + (dt[7] - '0');
+	cmd += (val & 0xFF);
+	cmd.append(post);
+	set_trace(1, "set xcvr clock");
+	waitFB("set xcvr clock", 200);
+	seth();
+}
+
+// ---------------------------------------------------------------------
+// tm formated as HH:MM:SS
+// ---------------------------------------------------------------------
+void RIG_IC7100::sync_clock(char *tm)
+{
+	cmd.clear();
+	cmd.append(pre_to);
+	cmd += '\x1A'; cmd += '\x05';
+	cmd += '\x01'; cmd += '\x21';
+	unsigned char val;
+	val = ((tm[0] - '0') << 4) + (tm[1] - '0');
+	cmd += (val & 0xFF);
+	val = ((tm[3] - '0') << 4) + (tm[4] - '0');
+	cmd += (val & 0xFF);
+	cmd.append(post);
+	set_trace(1, "set xcvr clock");
+	waitFB("set xcvr clock", 200);
+	seth();
+}
+
