@@ -253,6 +253,8 @@ RIG_IC7300::RIG_IC7300() {
 	can_change_alt_vfo = true;
 	has_a2b = true;
 
+	can_synch_clock = true;
+
 	CW_sense = 0; // CW is LSB
 
 //	progStatus.gettrace   = 
@@ -383,6 +385,55 @@ void RIG_IC7300::set_xcvr_auto_off()
 	seth();
 }
 
+// ---------------------------------------------------------------------
+// set date and time
+// 1A 05 00 95 HH MM : set time
+// 1A 05 00 94 YY YY MM DD : set date
+// ---------------------------------------------------------------------
+// dt formated as YYYYMMDD
+// ---------------------------------------------------------------------
+void RIG_IC7300::sync_date(char *dt)
+{
+	cmd.clear();
+	cmd.append(pre_to);
+	cmd += '\x1A'; cmd += '\x05';
+	cmd += '\x00'; cmd += '\x94';
+	unsigned char val;
+	val = ((dt[0] - '0') << 4) + (dt[1] - '0');
+	cmd += (val & 0xFF);
+	val = ((dt[2] - '0') << 4) + (dt[3] - '0');
+	cmd += (val & 0xFF);
+	val = ((dt[4] - '0') << 4) + (dt[5] - '0');
+	cmd += (val & 0xFF);
+	val = ((dt[6] - '0') << 4) + (dt[7] - '0');
+	cmd += (val & 0xFF);
+	cmd.append(post);
+	set_trace(1, "set xcvr clock");
+	waitFB("set xcvr clock", 200);
+	seth();
+}
+
+// ---------------------------------------------------------------------
+// tm formated as HH:MM:SS
+// ---------------------------------------------------------------------
+void RIG_IC7300::sync_clock(char *tm)
+{
+	cmd.clear();
+	cmd.append(pre_to);
+	cmd += '\x1A'; cmd += '\x05';
+	cmd += '\x00'; cmd += '\x95';
+	unsigned char val;
+	val = ((tm[0] - '0') << 4) + (tm[1] - '0');
+	cmd += (val & 0xFF);
+	val = ((tm[3] - '0') << 4) + (tm[4] - '0');
+	cmd += (val & 0xFF);
+	cmd.append(post);
+	set_trace(1, "set xcvr clock");
+	waitFB("set xcvr clock", 200);
+	seth();
+}
+
+
 bool RIG_IC7300::check ()
 {
 	if (xcvr_is_on) return true;
@@ -1415,7 +1466,7 @@ void RIG_IC7300::set_power_control(double val)
 
 }
 
-int RIG_IC7300::get_power_control()
+double RIG_IC7300::get_power_control()
 {
 	int val = progStatus.power_level;
 	string cstr = "\x14\x0A";
@@ -2280,11 +2331,17 @@ void RIG_IC7300::setVfoAdj(double v)
 	cmd.append("\x1A\x05");
 	cmd += '\x00';
 	cmd += '\x58';
-	cmd.append(bcd255(int(v)));
+	int vint = roundf(v * 2.55);
+	cmd += (vint / 100);
+	vint %= 100;
+	cmd += ((vint % 10) + ((vint / 10) << 4));
 	cmd.append(post);
 	set_trace(1, "set VFO adjust");
 	waitFB("SET vfo adjust");
 	seth();
+
+	MilliSleep(100);
+	getVfoAdj();
 }
 
 double RIG_IC7300::getVfoAdj()
@@ -2302,12 +2359,20 @@ double RIG_IC7300::getVfoAdj()
 	if (ret) {
 		size_t p = replystr.find(pre_fm);
 		if (p != string::npos) {
-			vfo_ = num100(replystr.substr(p+8));
+			vfo_ = 100 * (replystr[p+8] & 0x0F) + 10 * ((replystr[p+9] & 0xF0) >> 4) + (replystr[p+9] & 0x0F);
+			vfo_ /= 2.55;
 		}
 	}
 	return vfo_;
 }
 
+void RIG_IC7300::get_vfoadj_min_max_step(double &min, double &max, double &step)
+{
+	min = 0; 
+	max = 100; 
+	step = 0.3922;
+}
+
 // Read/Write band stack registers
 //
 // Read 23 bytes
