@@ -177,7 +177,9 @@ RIG_FT991::RIG_FT991() {
 	has_preamp_control =
 	has_ifshift_control =
 	has_ptt_control =
-	has_tune_control = true;
+	has_tune_control =
+	can_synch_clock = true;
+
 
 // derived specific
 	atten_level = 1;
@@ -469,7 +471,7 @@ int RIG_FT991::get_power_out()
 }
 
 // Transceiver power level
-int RIG_FT991::get_power_control()
+double RIG_FT991::get_power_control()
 {
 	cmd = rsp = "PC";
 	cmd += ';';
@@ -1377,7 +1379,7 @@ double RIG_FT991::getVfoAdj()
 	return (double)(atoi(&replystr[p+5]));
 }
 
-void RIG_FT991::get_vfoadj_min_max_step(int &min, int &max, int &step)
+void RIG_FT991::get_vfoadj_min_max_step(double &min, double &max, double &step)
 {
 	min = -25;
 	max = 25;
@@ -1413,3 +1415,33 @@ int RIG_FT991::get_break_in()
 	return progStatus.break_in;
 }
 
+// ---------------------------------------------------------------------
+// set date and time
+// ---------------------------------------------------------------------
+// dt formated as YYYYMMDD
+// ---------------------------------------------------------------------
+void RIG_FT991::sync_date(char *dt)
+{
+	cmd.assign("DT0");
+	cmd.append(dt);
+	cmd += ';';
+	sendCommand(cmd);
+	showresp(WARN, ASC, "sync_date", cmd, replystr);
+	sett("sync_date");
+}
+
+// ---------------------------------------------------------------------
+// tm formated as HH:MM:SS
+// ---------------------------------------------------------------------
+void RIG_FT991::sync_clock(char *tm)
+{
+	cmd.assign("DT1");
+	cmd += tm[0]; cmd += tm[1];
+	cmd += tm[3]; cmd += tm[4];
+	cmd += tm[6]; cmd += tm[7];
+	cmd += ';';
+	sendCommand(cmd);
+	showresp(WARN, ASC, "sync_time", cmd, replystr);
+	sett("sync_time");
+}
+
