@@ -178,7 +178,8 @@ RIG_FT991A::RIG_FT991A() {
 	has_preamp_control =
 	has_ifshift_control =
 	has_ptt_control =
-	has_tune_control = true;
+	has_tune_control =
+	can_synch_clock = true;
 
 // derived specific
 	atten_level = 1;
@@ -487,7 +488,7 @@ int RIG_FT991A::get_power_out()
 }
 
 // Transceiver power level
-int RIG_FT991A::get_power_control()
+double RIG_FT991A::get_power_control()
 {
 	cmd = rsp = "PC";
 	cmd += ';';
@@ -564,7 +565,10 @@ int RIG_FT991A::get_PTT()
 
 	size_t p = replystr.rfind(rsp);
 	if (p == string::npos) return ptt_;
-	ptt_ =  (replystr[p+2] != '0' ? 1 : 0);
+	switch (replystr[p+2]) {
+		default: case '0' : ptt_ = false; break;
+		case '1': case '2': ptt_ = true; break;
+	}
 	return ptt_;
 }
 
@@ -1447,7 +1451,7 @@ double RIG_FT991A::getVfoAdj()
 	return (double)(atoi(&replystr[p+5]));
 }
 
-void RIG_FT991A::get_vfoadj_min_max_step(int &min, int &max, int &step)
+void RIG_FT991A::get_vfoadj_min_max_step(double &min, double &max, double &step)
 {
 	min = -25;
 	max = 25;
@@ -1491,3 +1495,35 @@ int RIG_FT991A::get_break_in()
 	return progStatus.break_in;
 }
 
+// ---------------------------------------------------------------------
+// set date and time
+// 1A 05 00 95 HH MM : set time
+// 1A 05 00 94 YY YY MM DD : set date
+// ---------------------------------------------------------------------
+// dt formated as YYYYMMDD
+// ---------------------------------------------------------------------
+void RIG_FT991A::sync_date(char *dt)
+{
+	cmd.assign("DT0");
+	cmd.append(dt);
+	cmd += ';';
+	sendCommand(cmd);
+	showresp(WARN, ASC, "sync_date", cmd, replystr);
+	sett("sync_date");
+}
+
+// ---------------------------------------------------------------------
+// tm formated as HH:MM:SS
+// ---------------------------------------------------------------------
+void RIG_FT991A::sync_clock(char *tm)
+{
+	cmd.assign("DT1");
+	cmd += tm[0]; cmd += tm[1];
+	cmd += tm[3]; cmd += tm[4];
+	cmd += tm[6]; cmd += tm[7];
+	cmd += ';';
+	sendCommand(cmd);
+	showresp(WARN, ASC, "sync_time", cmd, replystr);
+	sett("sync_time");
+}
+
