@@ -78,7 +78,7 @@ public:
 	rig_get_xcvr(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_xcvr", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online)
+		if (!xcvr_online || disable_xmlrpc->value())
 			result = "";
 		else
 			result = selrig->name_;
@@ -198,7 +198,7 @@ public:
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
 		string info = "";
 
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = info;
 			return;
 		}
@@ -230,19 +230,19 @@ public:
 		string info;  info.clear();
 		string temp;  temp.clear();
 
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = info;
 			return;
 		}
 
 		if (selrig->has_smeter && !btnPTT->value()) {
 			static char szval[10];
-			snprintf(szval, sizeof(szval), "S:%d\n", (int)mval);
+			snprintf(szval, sizeof(szval), "S:%5.0f\n", smtrval);
 			info.append(szval);
 		}
 		if (selrig->has_power_out && btnPTT->value()) {
 			static char szval[10];
-			snprintf(szval, sizeof(szval), "P:%d\n", (int)pwrval);
+			snprintf(szval, sizeof(szval), "P:%5.0f\n", pwrval);
 			info.append(szval);
 		}
 
@@ -332,7 +332,7 @@ public:
 	rig_get_vfo(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_vfo", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = "14070000";
 			return;
 		}
@@ -371,7 +371,7 @@ public:
 	rig_get_vfoA(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_vfoA", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = "14070000";
 			return;
 		}
@@ -402,7 +402,7 @@ public:
 	rig_get_vfoB(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_vfoB", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = "14070000";
 			return;
 		}
@@ -432,7 +432,7 @@ public:
 	rig_get_AB(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_AB", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = "A";
 			return;
 		}
@@ -457,7 +457,7 @@ public:
 	rig_get_notch(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_notch", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -481,7 +481,7 @@ public:
 	rig_set_notch(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_notch", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -509,7 +509,7 @@ public:
 	rig_set_verify_notch(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_verify_notch", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -542,7 +542,7 @@ public:
 	rig_get_rfgain(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_rfgain", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -567,7 +567,7 @@ public:
 	rig_set_rfgain(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_rfgain", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -591,7 +591,7 @@ public:
 	rig_set_verify_rfgain(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_verify_rfgain", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -623,7 +623,7 @@ public:
 	rig_get_micgain(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_micgain", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -648,7 +648,7 @@ public:
 	rig_set_micgain(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_micgain", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -672,7 +672,7 @@ public:
 	rig_set_verify_micgain(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_verify_micgain", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -704,7 +704,7 @@ public:
 	rig_get_volume(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_volume", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -729,7 +729,7 @@ public:
 	rig_set_volume(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_volume", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -753,7 +753,7 @@ public:
 	rig_set_verify_volume(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_verify_volume", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -786,7 +786,7 @@ public :
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
 		XmlRpcValue modes;
 
-		if (!xcvr_online || !selrig->modes_) {
+		if (!xcvr_online || disable_xmlrpc->value() || !selrig->modes_) {
 			modes[0] = "CW";
 			modes[1] = "LSB";
 			modes[2] = "USB";
@@ -819,7 +819,7 @@ public:
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
 
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = "U";
 			return;
 		}
@@ -850,7 +850,7 @@ public:
 	rig_get_mode(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_mode", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = "USB";
 			return;
 		}
@@ -881,7 +881,7 @@ public:
 	rig_get_modeA(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_modeA", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = "USB";
 			return;
 		}
@@ -912,7 +912,7 @@ public:
 	rig_get_modeB(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_modeB", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = "USB";
 			return;
 		}
@@ -944,7 +944,7 @@ public :
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
 
-		if (!xcvr_online || !selrig->bandwidths_) {
+		if (!xcvr_online || disable_xmlrpc->value() || !selrig->bandwidths_) {
 			XmlRpcValue bws;
 			bws[0][0] = "Bandwidth";
 			bws[0][1] = "NONE";
@@ -1013,7 +1013,7 @@ public:
 		result[0] = "NONE";
 		result[1] = "";
 
-		if (!xcvr_online) return;
+		if (!xcvr_online || disable_xmlrpc->value()) return;
 
 		wait();
 		guard_lock service_lock(&mutex_srvc_reqs, "xml rig_get_bw");
@@ -1072,7 +1072,7 @@ public:
 		result[0] = "NONE";
 		result[1] = "";
 
-		if (!xcvr_online) return;
+		if (!xcvr_online || disable_xmlrpc->value()) return;
 
 		wait();
 		guard_lock service_lock(&mutex_srvc_reqs, "xml rig_get_bwA");
@@ -1132,7 +1132,7 @@ public:
 		result[0] = "NONE";
 		result[1] = "";
 
-		if (!xcvr_online) return;
+		if (!xcvr_online || disable_xmlrpc->value()) return;
 
 		wait();
 		guard_lock service_lock(&mutex_srvc_reqs, "xml rig_get_bwB");
@@ -1183,7 +1183,7 @@ public:
 	rig_get_smeter(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_smeter", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online || !selrig->has_smeter)
+		if (!xcvr_online || disable_xmlrpc->value() || !selrig->has_smeter)
 			result = "0";
 		else {
 			guard_lock serial_lock(&mutex_serial);
@@ -1205,7 +1205,7 @@ public:
 	rig_get_DBM(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_DBM", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online || !selrig->has_smeter)
+		if (!xcvr_online || disable_xmlrpc->value() || !selrig->has_smeter)
 			result = "0";
 		else {
 			guard_lock serial_lock(&mutex_serial);
@@ -1229,7 +1229,7 @@ public:
 	rig_get_Sunits(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_Sunits", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online || !selrig->has_smeter)
+		if (!xcvr_online || disable_xmlrpc->value() || !selrig->has_smeter)
 			result = "0";
 		else {
 			guard_lock serial_lock(&mutex_serial);
@@ -1257,7 +1257,7 @@ public:
 	rig_get_pwrmeter_scale(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_pwrmeter_scale", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online || !selrig->has_power_out)
+		if (!xcvr_online || disable_xmlrpc->value() || !selrig->has_power_out)
 			result = (int)(0);
 		else {
 			guard_lock serial_lock(&mutex_serial);
@@ -1284,7 +1284,7 @@ public:
 	rig_get_pwrmeter(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_pwrmeter", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online || !selrig->has_power_out)
+		if (!xcvr_online || disable_xmlrpc->value() || !selrig->has_power_out)
 			result = "0";
 		else {
 			guard_lock serial_lock(&mutex_serial);
@@ -1306,7 +1306,7 @@ public:
 	rig_get_swrmeter(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_swrmeter", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online || !selrig->has_swr_control)
+		if (!xcvr_online || disable_xmlrpc->value() || !selrig->has_swr_control)
 			result = "0";
 		else {
 			guard_lock serial_lock(&mutex_serial);
@@ -1352,7 +1352,7 @@ public:
 	rig_set_power(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_power", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1373,7 +1373,7 @@ public:
 	rig_set_verify_power(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_verify_power", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1412,7 +1412,7 @@ public:
 	rig_tune(XmlRpcServer* s) : XmlRpcServerMethod("rig.tune", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1436,7 +1436,7 @@ public:
 	rig_set_verify_ptt(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_verify_ptt", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1470,7 +1470,7 @@ public:
 	rig_set_ptt(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_ptt", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1492,7 +1492,7 @@ public:
 	rig_set_ptt_fast(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_ptt_fast", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1522,7 +1522,7 @@ public:
 	rig_swap(XmlRpcServer* s) : XmlRpcServerMethod("rig.swap", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1544,7 +1544,7 @@ public:
 	rig_set_swap(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_swap", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1566,7 +1566,7 @@ public:
 	rig_set_verify_swap(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_verify_swap", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1592,7 +1592,7 @@ public:
 	rig_set_split(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_split", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1620,7 +1620,7 @@ public:
 	rig_set_verify_split(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_verify_split", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1663,7 +1663,7 @@ public:
 	rig_set_AB(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_AB", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1696,7 +1696,7 @@ public:
 	rig_set_verify_AB(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_verify_AB", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1733,7 +1733,7 @@ public:
 	rig_set_vfoA(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_vfoA", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1763,7 +1763,7 @@ public:
 	rig_set_verify_vfoA(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_verify_vfoA", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1792,7 +1792,7 @@ public:
 	rig_set_vfoA_fast(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_vfoA_fast", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1825,7 +1825,7 @@ public:
 	rig_set_vfoB(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_vfoB", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1854,7 +1854,7 @@ public:
 	rig_set_verify_vfoB(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_verify_vfoB", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1883,7 +1883,7 @@ public:
 	rig_set_vfoB_fast(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_vfoB_fast", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1916,7 +1916,7 @@ public:
 	rig_set_vfo(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_vfo", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1943,7 +1943,7 @@ public:
 	rig_set_verify_vfo(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_verify_vfo", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1971,7 +1971,7 @@ public:
 	main_set_frequency(XmlRpcServer* s) : XmlRpcServerMethod("main.set_frequency", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -1998,7 +1998,7 @@ public:
 	rig_set_frequency(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_frequency", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -2026,7 +2026,7 @@ public:
 	rig_set_verify_frequency(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_verify_frequency", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -2058,7 +2058,7 @@ public:
 	rig_set_mode(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_mode", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue &result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -2105,7 +2105,7 @@ public:
 
 	void execute(XmlRpcValue& params, XmlRpcValue &result) {
 		result = 0;
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			return;
 		}
 
@@ -2156,7 +2156,7 @@ public:
 	rig_set_modeA(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_modeA", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue &result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -2199,7 +2199,7 @@ public:
 
 	void execute(XmlRpcValue& params, XmlRpcValue &result) {
 		result = 0;
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			return;
 		}
 
@@ -2243,7 +2243,7 @@ public:
 	rig_set_modeB(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_modeB", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue &result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -2285,7 +2285,7 @@ public:
 
 	void execute(XmlRpcValue& params, XmlRpcValue &result) {
 		result= 0;
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			return;
 		}
 
@@ -2328,7 +2328,7 @@ public:
 	rig_set_bandwidth(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_bandwidth", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -2370,7 +2370,7 @@ public:
 	rig_set_verify_bandwidth(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_verify_bandwidth", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -2417,7 +2417,7 @@ public:
 	rig_set_bw(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_bw", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -2446,7 +2446,7 @@ public:
 	rig_set_verify_bw(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_verify_bw", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -2480,7 +2480,7 @@ public:
 	rig_set_BW(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_BW", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -2513,7 +2513,7 @@ public:
 	rig_set_verify_BW(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_verify_BW", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
@@ -2551,7 +2551,7 @@ public:
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
 		result = 0;
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			return;
 		}
 		std::string command = std::string(params[0]);
@@ -2601,7 +2601,7 @@ public:
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
 		result = 0;
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			return;
 		}
 		std::string command = std::string(params[0]);
@@ -2735,7 +2735,7 @@ public:
 	rig_shutdown(XmlRpcServer* s) : XmlRpcServerMethod("rig.shutdown", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!xcvr_online) {
+		if (!xcvr_online || disable_xmlrpc->value()) {
 			result = 0;
 			return;
 		}
